==> eagle-i-repository-webapp-1.0-MS6.11-sources.jar: jsp/repository/admin/editGraph_jsp.java <==
package jsp.repository.admin;

import javax.servlet.*;
import javax.servlet.http.*;
import javax.servlet.jsp.*;
import java.io.IOException;
import java.util.Arrays;
import java.util.Collection;
import org.apache.commons.lang.StringEscapeUtils;
import org.openrdf.model.URI;
import org.openrdf.repository.RepositoryConnection;
import org.eaglei.repository.NamedGraph;
import org.eaglei.repository.Provenance;
import org.eaglei.repository.servlet.WithRepositoryConnection;
import org.eaglei.repository.status.ErrorSendingException;
import org.eaglei.repository.vocabulary.DCTERMS;
import javax.servlet.http.HttpServletResponse;
import org.apache.log4j.Logger;
import org.apache.log4j.LogManager;
import org.openrdf.model.Literal;
import org.openrdf.model.Value;
import org.openrdf.model.URI;
import org.openrdf.model.impl.URIImpl;
import org.eaglei.repository.NamedGraph;
import org.eaglei.repository.status.ErrorSendingException;
import org.eaglei.repository.servlet.WithRepositoryConnection;
import org.eaglei.repository.DataRepository;

public final class editGraph_jsp extends org.apache.jasper.runtime.HttpJspBase
    implements org.apache.jasper.runtime.JspSourceDependent {


    // output a provenance "entry" for created or modified, they are similar.
    private void provEntry(HttpServletRequest request, JspWriter out, Provenance p, String label, String when, String who)
        throws IOException
    {
        if (when == null)
            return;
        String whoLabel = null;
        if (who != null)
            whoLabel = p.getField(request, new URIImpl(who));
        out.append("<li><b>").append(label).append(":</b> <tt>").
            append(when).append("</tt>");
        if (who != null) {
            out.append(", by ");
            if (whoLabel == null)
                out.append(who);
            else
                out.append("<a href=\"").append(who).append("\">").
                    append(whoLabel).append("</a>");
        }
        out.append("</li>");
    }

  private static final JspFactory _jspxFactory = JspFactory.getDefaultFactory();

  private static java.util.List _jspx_dependants;

  static {
    _jspx_dependants = new java.util.ArrayList(1);
    _jspx_dependants.add("/repository/admin/banner.jsp");
  }

  private javax.el.ExpressionFactory _el_expressionfactory;
  private org.apache.AnnotationProcessor _jsp_annotationprocessor;

  public Object getDependants() {
    return _jspx_dependants;
  }

  public void _jspInit() {
    _el_expressionfactory = _jspxFactory.getJspApplicationContext(getServletConfig().getServletContext()).getExpressionFactory();
    _jsp_annotationprocessor = (org.apache.AnnotationProcessor) getServletConfig().getServletContext().getAttribute(org.apache.AnnotationProcessor.class.getName());
  }

  public void _jspDestroy() {
  }

  public void _jspService(HttpServletRequest request, HttpServletResponse response)
        throws java.io.IOException, ServletException {

    PageContext pageContext = null;
    HttpSession session = null;
    ServletContext application = null;
    ServletConfig config = null;
    JspWriter out = null;
    Object page = this;
    JspWriter _jspx_out = null;
    PageContext _jspx_page_context = null;


    try {
      response.setContentType("text/html");
      pageContext = _jspxFactory.getPageContext(this, request, response,
      			null, true, 8192, true);
      _jspx_page_context = pageContext;
      application = pageContext.getServletContext();
      config = pageContext.getServletConfig();
      session = pageContext.getSession();
      out = pageContext.getOut();
      _jspx_out = out;

      out.write("<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Strict//EN\"\n \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\">\n<html xmlns=\"http://www.w3.org/1999/xhtml\" lang=\"en\" xml:lang=\"en\">\n");
      out.write("\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n  <head>\n    <title>Eagle-I Data Repository Admin - Edit Named Graph Metadata</title>\n  </head>\n\n");
      out.write('\n');
      out.write('\n');
      out.write('\n');

    try {
        // feedback message about status of any chosen operation
        String message = null;
        boolean messageSuccess = false;

        // sanity-check args
        String rawname = request.getParameter("name");
        if (rawname == null) {
            response.sendError(HttpServletResponse.SC_BAD_REQUEST, "Missing the required argument 'name'");
            return;
        }

        URI name = null;
        try {
            name = new URIImpl(rawname);
        } catch (IllegalArgumentException e) {
            response.sendError(HttpServletResponse.SC_BAD_REQUEST, "Illegal URI for name: "+e);
            return;
        }
        NamedGraph ng = NamedGraph.find(request, name);
        if (ng == null) {
            response.sendError(HttpServletResponse.SC_BAD_REQUEST, "Not a named graph or unmanaged context URI: "+name);
            return;
        }

        // if request to modify properties was submitted there will be
        // value for 'submit' and others:
        String type = request.getParameter("type");
        String label = request.getParameter("label");
        if (request.getParameter("submit") != null) {
            if (type != null && type.length() > 0 &&
                label != null && label.length() > 0) {
                URI utype = null;
                try {
                    utype = new URIImpl(type);
                } catch (IllegalArgumentException e) {
                    response.sendError(HttpServletResponse.SC_BAD_REQUEST, "Illegal URI for type: "+e);
                    return;
                }
                ng.setLabel(request, label);
                ng.setType(request, utype);
                ng.commit(request);
                messageSuccess = true;
                message = "Named Graph has been modified.";
            } else {
                messageSuccess = false;
                message = "You must supply values for label and type.";
            }
        }

        String slabel = ng.getLabel();
        if (slabel == null)
            slabel = "";

      out.write("\n  <body>\n    ");
      out.write("\n\n\n<hr/>\n    <table border=\"0\" width=\"100%\" >\n      <tr>\n        <td width=\"30%\"><a href=\"http://www.eagle-i.org/\"><img border=\"0\" alt=\"Institutional Logo\" align=\"right\"\n               src=\"");
      out.print( DataRepository.getInstance().getConfigurationProperty("eaglei.repository.logo", "/repository/images/eagle-i_admin_logo.png") );
      out.write("\" /></a>\n        </td>\n        <td width=\"40%\"><div align=\"center\">\n          <font size=\"+2\" color=\"black\">\n            Repository Administration Area\n          </font>\n          <p>");
      out.print( DataRepository.getInstance().getConfigurationProperty("eaglei.repository.title", "(Config property <tt>eaglei.repository.title</tt> needs to be set)") );
      out.write("</p>\n        </div></td>\n        <td width=\"30%\">&nbsp;</td>\n      </tr>\n    </table>\n<hr/>\n");
      out.write("\n    <h2 align=\"center\">Edit Named Graph Metadata</h2>\n    <h3 align=\"center\"><tt>");
      out.print( name.toString() );
      out.write("</tt></h3>\n");

    if (message != null) {

      out.write("\n      <h3><font color=\"");
      out.print( messageSuccess ? "GREEN" : "RED" );
      out.write("\">\n          ");
      out.print( messageSuccess ? "Success" : "FAILED" );
      out.write(':');
      out.write(' ');
      out.print( StringEscapeUtils.escapeHtml(message) );
      out.write("\n          </font>\n     </h3>\n");

    }

      out.write('\n');
      out.write('\n');

    Provenance p = new Provenance(name);
    String created = p.getField(request, DCTERMS.CREATED);
    String creator = p.getField(request, DCTERMS.CREATOR);
    String modified = p.getField(request, DCTERMS.MODIFIED);
    String contributor = p.getField(request, DCTERMS.CONTRIBUTOR);
    String sourceIdentifier = p.getField(request, DCTERMS.SOURCE_IDENTIFIER);
    String sourceModified = p.getField(request, DCTERMS.SOURCE_MODIFIED);
    if (created != null || modified != null || sourceIdentifier != null) {

      out.write("\n    <h3>Provenance Metadata:</h3>\n    <ul>\n");

        provEntry(request, out, p, "Created", created, creator);
        provEntry(request, out, p, "Last modified", modified, contributor);

      out.write('\n');
      out.write('\n');

        if (sourceIdentifier != null) {

      out.write("\n        <li><b>From:</b> <tt>");
      out.print( sourceIdentifier );
      out.write("</tt>\n");

            if (sourceModified != null) {

      out.write(", last modified <tt>");
      out.print( sourceModified );
      out.write("</tt>\n");

            }

      out.write("\n        </li>\n");

        }

      out.write("\n    </ul>\n");

    }

      out.write("\n\n    <form action=\"\">\n      <fieldset style=\"width: 80%; align: center;\">\n       <legend><b>Modify Named Graph Properties</b></legend>\n       <input type=\"hidden\" name=\"name\" value=\"");
      out.print( name.toString() );
      out.write("\"/>\n       <p><b>Label:</b> <input type=\"text\" name=\"label\" size=\"50\" value=\"");
      out.print( slabel );
      out.write("\"/>\n       </p>\n       <p><b>Named Graph Type:</b> <select name=\"type\">\n");

    if (ng.getType() == null) {

      out.write("\n          <option selected=\"t\" value=\"\"> --none-- </option>\n");

    }
    for (NamedGraph.Type t : NamedGraph.Type.values()) {

      out.write("\n          <option ");
      out.print( t == ng.getType() ? "selected=\"t\"" : "" );
      out.write("\n            value=\"");
      out.print( t.uri );
      out.write("\">\n            ");
      out.print( StringEscapeUtils.escapeHtml(t.getTitle()) );
      out.write("\n          </option>\n");

    }

      out.write("\n        </select>\n        </p>\n        <div width=\"50%\" align=\"left\">\n          <div width=\"50%\" align=\"center\">\n            <button type=\"reset\">Reset Form</button>\n            &nbsp;&nbsp;&nbsp;&nbsp;\n            <button name=\"submit\" value=\"submit\" type=\"submit\">Submit</button>\n          </div>\n        </div>\n      </fieldset>\n    </form>\n\n    <form  action=\"/repository/admin/editGrants.jsp\">\n      <fieldset style=\"width: 80%; align: center;\">\n       <legend><b>Change Named Graph Access</b></legend>\n      <input type=\"hidden\" name=\"type\" value=\"Named Graph\" />\n      <input type=\"hidden\" name=\"label\" value=\"");
      out.print( slabel );
      out.write("\"/>\n      <input type=\"hidden\" name=\"uri\" value=\"");
      out.print( ng.getName() );
      out.write("\"/>\n      <button type=\"submit\">Edit ACL</button><i> (Leaves this page)</i>\n     </fieldset>\n    </form>\n    <p></p>\n    <p>\n    <a href=\"/repository/admin/namedGraphs.jsp\">Return to Named Graphs</a>\n    </p>\n    <p>\n    <a href=\"/repository/admin/index.jsp\">Return to Admin top level</a>\n    </p>\n  </body>\n");

    // see "try" at start of body tag.
    } catch (ErrorSendingException e) {
        response.sendError(e.getStatus(), e.getMessage());
    }

      out.write("\n</html>\n");
    } catch (Throwable t) {
      if (!(t instanceof SkipPageException)){
        out = _jspx_out;
        if (out != null && out.getBufferSize() != 0)
          try { out.clearBuffer(); } catch (java.io.IOException e) {}
        if (_jspx_page_context != null) _jspx_page_context.handlePageException(t);
      }
    } finally {
      _jspxFactory.releasePageContext(_jspx_page_context);
    }
  }
}

==> eagle-i-repository-webapp-1.1-MS1.01-sources.jar: jsp/repository/admin/editGraph_jsp.java <==
package jsp.repository.admin;

import javax.servlet.*;
import javax.servlet.http.*;
import javax.servlet.jsp.*;
import java.io.IOException;
import java.util.Arrays;
import java.util.Collection;
import org.apache.commons.lang.StringEscapeUtils;
import org.openrdf.model.URI;
import org.openrdf.repository.RepositoryConnection;
import org.eaglei.repository.NamedGraph;
import org.eaglei.repository.Provenance;
import org.eaglei.repository.servlet.WithRepositoryConnection;
import org.eaglei.repository.status.ErrorSendingException;
import org.eaglei.repository.vocabulary.DCTERMS;
import javax.servlet.http.HttpServletResponse;
import org.apache.log4j.Logger;
import org.apache.log4j.LogManager;
import org.openrdf.model.Literal;
import org.openrdf.model.Value;
import org.openrdf.model.URI;
import org.openrdf.model.impl.URIImpl;
import org.eaglei.repository.NamedGraph;
import org.eaglei.repository.status.ErrorSendingException;
import org.eaglei.repository.servlet.WithRepositoryConnection;
import org.eaglei.repository.DataRepository;

public final class editGraph_jsp extends org.apache.jasper.runtime.HttpJspBase
    implements org.apache.jasper.runtime.JspSourceDependent {


    // output a provenance "entry" for created or modified, they are similar.
    private void provEntry(HttpServletRequest request, JspWriter out, Provenance p, String label, String when, String who)
        throws IOException
    {
        if (when == null)
            return;
        String whoLabel = null;
        if (who != null)
            whoLabel = p.getField(request, new URIImpl(who));
        out.append("<li><b>").append(label).append(":</b> <tt>").
            append(when).append("</tt>");
        if (who != null) {
            out.append(", by ");
            if (whoLabel == null)
                out.append(who);
            else
                out.append("<a href=\"").append(who).append("\">").
                    append(whoLabel).append("</a>");
        }
        out.append("</li>");
    }

  private static final JspFactory _jspxFactory = JspFactory.getDefaultFactory();

  private static java.util.List _jspx_dependants;

  static {
    _jspx_dependants = new java.util.ArrayList(1);
    _jspx_dependants.add("/repository/admin/banner.jsp");
  }

  private javax.el.ExpressionFactory _el_expressionfactory;
  private org.apache.AnnotationProcessor _jsp_annotationprocessor;

  public Object getDependants() {
    return _jspx_dependants;
  }

  public void _jspInit() {
    _el_expressionfactory = _jspxFactory.getJspApplicationContext(getServletConfig().getServletContext()).getExpressionFactory();
    _jsp_annotationprocessor = (org.apache.AnnotationProcessor) getServletConfig().getServletContext().getAttribute(org.apache.AnnotationProcessor.class.getName());
  }

  public void _jspDestroy() {
  }

  public void _jspService(HttpServletRequest request, HttpServletResponse response)
        throws java.io.IOException, ServletException {

    PageContext pageContext = null;
    HttpSession session = null;
    ServletContext application = null;
    ServletConfig config = null;
    JspWriter out = null;
    Object page = this;
    JspWriter _jspx_out = null;
    PageContext _jspx_page_context = null;


    try {
      response.setContentType("text/html;charset=UTF-8");
      pageContext = _jspxFactory.getPageContext(this, request, response,
      			null, true, 8192, true);
      _jspx_page_context = pageContext;
      application = pageContext.getServletContext();
      config = pageContext.getServletConfig();
      session = pageContext.getSession();
      out = pageContext.getOut();
      _jspx_out = out;

      out.write("\n<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Strict//EN\"\n \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\">\n<html xmlns=\"http://www.w3.org/1999/xhtml\" lang=\"en\" xml:lang=\"en\">\n");
      out.write("\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n  <head>\n    <meta http-equiv=\"content-type\" content=\"text/html; charset=UTF-8\"/>\n    <title>Eagle-I Data Repository Admin - Edit Named Graph Metadata</title>\n  </head>\n\n");
      out.write('\n');
      out.write('\n');
      out.write('\n');

    try {
        // feedback message about status of any chosen operation
        String message = null;
        boolean messageSuccess = false;

        // sanity-check args
        String rawname = request.getParameter("name");
        if (rawname == null) {
            response.sendError(HttpServletResponse.SC_BAD_REQUEST, "Missing the required argument 'name'");
            return;
        }

        URI name = null;
        try {
            name = new URIImpl(rawname);
        } catch (IllegalArgumentException e) {
            response.sendError(HttpServletResponse.SC_BAD_REQUEST, "Illegal URI for name: "+e);
            return;
        }
        NamedGraph ng = NamedGraph.find(request, name);
        if (ng == null) {
            response.sendError(HttpServletResponse.SC_BAD_REQUEST, "Not a named graph or unmanaged context URI: "+name);
            return;
        }

        // if request to modify properties was submitted there will be
        // value for 'submit' and others:
        String type = request.getParameter("type");
        String label = request.getParameter("label");
        if (request.getParameter("submit") != null) {
            if (type != null && type.length() > 0 &&
                label != null && label.length() > 0) {
                URI utype = null;
                try {
                    utype = new URIImpl(type);
                } catch (IllegalArgumentException e) {
                    response.sendError(HttpServletResponse.SC_BAD_REQUEST, "Illegal URI for type: "+e);
                    return;
                }
                ng.setLabel(request, label);
                ng.setType(request, utype);
                ng.commit(request);
                messageSuccess = true;
                message = "Named Graph has been modified.";
            } else {
                messageSuccess = false;
                message = "You must supply values for label and type.";
            }
        }

        String slabel = ng.getLabel();
        if (slabel == null)
            slabel = "";

      out.write("\n  <body>\n    ");
      out.write('\n');
      out.write("\n\n<hr/>\n    <table border=\"0\" width=\"100%\" >\n      <tr>\n        <td width=\"30%\"><a href=\"http://www.eagle-i.org/\"><img border=\"0\" alt=\"Institutional Logo\" align=\"right\"\n               src=\"");
      out.print( DataRepository.getInstance().getConfigurationProperty("eaglei.repository.logo", "/repository/images/eagle-i_admin_logo.png") );
      out.write("\" /></a>\n        </td>\n        <td width=\"40%\"><div align=\"center\">\n          <font size=\"+2\" color=\"black\">\n            Repository Administration Area\n          </font>\n          <p>");
      out.print( DataRepository.getInstance().getConfigurationProperty("eaglei.repository.title", "(Config property <tt>eaglei.repository.title</tt> needs to be set)") );
      out.write("</p>\n        </div></td>\n        <td width=\"30%\">&nbsp;</td>\n      </tr>\n    </table>\n<hr/>\n");
      out.write("\n    <h2 align=\"center\">Edit Named Graph Metadata</h2>\n    <h3 align=\"center\"><tt>");
      out.print( name.toString() );
      out.write("</tt></h3>\n");

    if (message != null) {

      out.write("\n      <h3><font color=\"");
      out.print( messageSuccess ? "GREEN" : "RED" );
      out.write("\">\n          ");
      out.print( messageSuccess ? "Success" : "FAILED" );
      out.write(':');
      out.write(' ');
      out.print( StringEscapeUtils.escapeHtml(message) );
      out.write("\n          </font>\n     </h3>\n");

    }

      out.write('\n');
      out.write('\n');

    Provenance p = new Provenance(name);
    String created = p.getField(request, DCTERMS.CREATED);
    String creator = p.getField(request, DCTERMS.CREATOR);
    String modified = p.getField(request, DCTERMS.MODIFIED);
    String contributor = p.getField(request, DCTERMS.CONTRIBUTOR);
    String sourceIdentifier = p.getField(request, DCTERMS.SOURCE_IDENTIFIER);
    String sourceModified = p.getField(request, DCTERMS.SOURCE_MODIFIED);
    if (created != null || modified != null || sourceIdentifier != null) {

      out.write("\n    <h3>Provenance Metadata:</h3>\n    <ul>\n");

        provEntry(request, out, p, "Created", created, creator);
        provEntry(request, out, p, "Last modified", modified, contributor);

      out.write('\n');
      out.write('\n');

        if (sourceIdentifier != null) {

      out.write("\n        <li><b>From:</b> <tt>");
      out.print( sourceIdentifier );
      out.write("</tt>\n");

            if (sourceModified != null) {

      out.write(", last modified <tt>");
      out.print( sourceModified );
      out.write("</tt>\n");

            }

      out.write("\n        </li>\n");

        }

      out.write("\n    </ul>\n");

    }

      out.write("\n\n    <form action=\"\">\n      <fieldset style=\"width: 80%; align: center;\">\n       <legend><b>Modify Named Graph Properties</b></legend>\n       <input type=\"hidden\" name=\"name\" value=\"");
      out.print( name.toString() );
      out.write("\"/>\n       <p><b>Label:</b> <input type=\"text\" name=\"label\" size=\"50\" value=\"");
      out.print( slabel );
      out.write("\"/>\n       </p>\n       <p><b>Named Graph Type:</b> <select name=\"type\">\n");

    if (ng.getType() == null) {

      out.write("\n          <option selected=\"t\" value=\"\"> --none-- </option>\n");

    }
    for (NamedGraph.Type t : NamedGraph.Type.values()) {

      out.write("\n          <option ");
      out.print( t == ng.getType() ? "selected=\"t\"" : "" );
      out.write("\n            value=\"");
      out.print( t.uri );
      out.write("\">\n            ");
      out.print( StringEscapeUtils.escapeHtml(t.getTitle()) );
      out.write("\n          </option>\n");

    }

      out.write("\n        </select>\n        </p>\n        <div width=\"50%\" align=\"left\">\n          <div width=\"50%\" align=\"center\">\n            <button type=\"reset\">Reset Form</button>\n            &nbsp;&nbsp;&nbsp;&nbsp;\n            <button name=\"submit\" value=\"submit\" type=\"submit\">Submit</button>\n          </div>\n        </div>\n      </fieldset>\n    </form>\n\n    <form  action=\"/repository/admin/editGrants.jsp\">\n      <fieldset style=\"width: 80%; align: center;\">\n       <legend><b>Change Named Graph Access</b></legend>\n      <input type=\"hidden\" name=\"type\" value=\"Named Graph\" />\n      <input type=\"hidden\" name=\"label\" value=\"");
      out.print( slabel );
      out.write("\"/>\n      <input type=\"hidden\" name=\"uri\" value=\"");
      out.print( ng.getName() );
      out.write("\"/>\n      <button type=\"submit\">Edit ACL</button><i> (Leaves this page)</i>\n     </fieldset>\n    </form>\n    <p></p>\n    <p>\n    <a href=\"/repository/admin/namedGraphs.jsp\">Return to Named Graphs</a>\n    </p>\n    <p>\n    <a href=\"/repository/admin/index.jsp\">Return to Admin top level</a>\n    </p>\n  </body>\n");

    // see "try" at start of body tag.
    } catch (ErrorSendingException e) {
        response.sendError(e.getStatus(), e.getMessage());
    }

      out.write("\n</html>\n");
    } catch (Throwable t) {
      if (!(t instanceof SkipPageException)){
        out = _jspx_out;
        if (out != null && out.getBufferSize() != 0)
          try { out.clearBuffer(); } catch (java.io.IOException e) {}
        if (_jspx_page_context != null) _jspx_page_context.handlePageException(t);
      }
    } finally {
      _jspxFactory.releasePageContext(_jspx_page_context);
    }
  }
}
